/* style.css
 *
 * Copyright 2020 Paulo Queiroz <pvaqueiroz@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

/*
window,
window decoration,
window actionbar {
    margin: 10px;
}

window:not(.maximized):not(.fullscreen):not(.csd),
window:not(.maximized):not(.fullscreen):not(.csd) actionbar,
window:not(.maximized):not(.fullscreen):not(.csd) decoration {
    border-radius: 8px;
}

headerbar.pretty {
    background: transparent;
    border-bottom-width: 0;
}*/
