
headerbar { border-bottom: none; }

.side-headerbar, .side-box {
    background: @theme_base_color;
    border-right: 1px solid darker(@theme_base_color);
}

.main-headerbar { background: @theme_bg_color; }
